@@ -9,13 +9,15 @@ our @ISA = qw(Exporter);
 our @EXPORT_OK = qw(
   resample
   resample_medians
-  median
+  resample_means
   select_kth
+  median
+  mean
 );
 our @EXPORT = qw();
 our %EXPORT_TAGS = ('all' => \@EXPORT_OK);
 
-our $VERSION = '0.04';
+our $VERSION = '0.05';
 
 require XSLoader;
 XSLoader::load('Statistics::CaseResampling', $VERSION);
@@ -44,9 +46,11 @@ Statistics::CaseResampling - Efficient resampling
   # of $n_resamples resample runs
   # this is vastly more efficient that doing the same thing with
   # repeated resample() calls
+  my $means = resample_means($sample, $n_resamples);
   
   # utility functions:
   print median([1..5]), "\n"; # prints 3
+  print mean([1..5]), "\n"; # prints 3, too, surprise!
   print select_kth([1..5], 1), "\n"; # inefficient way to calculate the minimum
 
 =head1 DESCRIPTION
@@ -86,6 +90,16 @@ customary C<:all> group.
 Returns a reference to an array containing N random elements from the
 input array, where N is the length of the original array.
 
+=head2 resample_medians(ARRAYREF, NMEDIANS)
+
+Returns a reference to an array containing the medians of
+C<NMEDIANS> resamples of the original input sample.
+
+=head2 resample_means(ARRAYREF, NMEANS)
+
+Returns a reference to an array containing the means of
+C<NMEANS> resamples of the original input sample.
+
 =head2 median(ARRAYREF)
 
 Calculates the median of a sample. Works in linear time thanks
@@ -95,6 +109,10 @@ is, here, defined as the C<n/2-1>th largest number and not
 the average of the C<n/2-1>th and the C<n/2>th number. This shouldn't
 matter for nontrivial sample sizes.
 
+=head2 mean(ARRAYREF)
+
+Calculates the meean of a sample.
+
 =head2 select_kth(ARRAYREF, K)
 
 Selects the kth smallest element from the sample.
@@ -104,14 +122,10 @@ You get the median with this definition of K:
   my $k = int(@$sample/2) + (@$sample & 1);
   my $median = select_kth($sample, $k);
 
-=head2 resample_medians(ARRAYREF, NMEDIANS)
-
-Returns a reference to an array containing the medians of
-C<NMEDIANS> resamples of the original input sample.
-
 =head1 TODO
 
-One could calculate other statistics than the median in C for performance.
+One could calculate other statistics than the median and mean
+in C for performance.
 
 =head1 SEE ALSO
 
